From 6bb49825b23f0511fa389ccf18e9cafc53e1a9ed Mon Sep 17 00:00:00 2001
From: gregor herrmann <gregoa@debian.org>
Date: Fri, 9 Dec 2011 00:55:55 +0100
Subject: [PATCH] dh_perl: add -S (_s_ameperl) switch

The -S switch will add e.g. "perl (>= 5.14.2)" and "perl (<< 5.14.3~)" to
the ${perl:Depends} variable for packages that need the exact perl version
they are built against.

Closes: #579112
---
 dh_perl |   20 ++++++++++++++++++--
 1 files changed, 18 insertions(+), 2 deletions(-)

diff --git a/dh_perl b/dh_perl
index bf2506c..161ac54 100755
--- a/dh_perl
+++ b/dh_perl
@@ -13,7 +13,7 @@ use Debian::Debhelper::Dh_Lib;
 
 =head1 SYNOPSIS
 
-B<dh_perl> [S<I<debhelper options>>] [B<-d>] [S<I<library dirs> ...>]
+B<dh_perl> [S<I<debhelper options>>] [B<-d>] [B<-V>] [B<-S>] [S<I<library dirs> ...>]
 
 =head1 DESCRIPTION
 
@@ -49,6 +49,14 @@ By default, scripts and architecture independent modules don't depend
 on any specific version of B<perl>. The B<-V> option causes the current
 version of the B<perl> (or B<perl-base> with B<-d>) package to be specified.
 
+=item B<-S>
+
+The B<-S> option (mnemonic: _s_ame perl version), adds B<perl (E<gt>=
+$currentversion)> and B<perl (<< $nextminorversion~)> to B<${perl:Depends}>
+(or B<perl-base> with B<-d>), in order to allow packages to depend on the
+exact same perl version they are built against. This is independent of
+arch:all or arch:any.
+
 =item I<library dirs>
 
 If your package installs Perl modules in non-standard
@@ -66,7 +74,7 @@ Perl policy, version 1.20
 
 =cut
 
-init();
+init(options => { S => \$dh{S_FLAG} });
 
 my $vendorlib = substr $Config{vendorlib}, 1;
 my $vendorarch = substr $Config{vendorarch}, 1;
@@ -131,6 +139,14 @@ foreach my $package (@{$dh{DOPACKAGES}}) {
 		addsubstvar($package, "perl:Depends",
 			"perlapi-" . ($Config{debian_abi} || $Config{version}))
 			if $deps & XS_MODULE;
+
+		if ($dh{S_FLAG}) {
+			my $currentversion = ">= $Config{version}";
+			my ($v1, $v2, $v3) = split /\./, $Config{version};
+			my $nextversion = "<< " . (join ".", $v1, $v2, $v3 + 1) . "~";
+			addsubstvar($package, "perl:Depends", $perl, $currentversion);
+			addsubstvar($package, "perl:Depends", $perl, $nextversion);
+		}
 	}
 
 	# MakeMaker always makes lib and share dirs, but typically
-- 
1.7.7.3

